@@ -13,17 +13,9 @@
 #ifndef YAFC_BASE64_H
 #define YAFC_BASE64_H
 
-#ifdef HAVE_CONFIG_H
-# include "config.h"
-#endif
-
-#ifdef HAVE_BASE64_HEIMDAL
-#include <heimdal/base64.h>
-#else
 #include <stddef.h>
 
-int base64_encode(const void* data, size_t size, char** str);
-int base64_decode(const char* str, void* data);
-#endif
+int b64_encode(const void* data, size_t size, char** str);
+int b64_decode(const char* str, void* data);
 
 #endif
