@@ -136,7 +136,7 @@ gss_overhead(void *app_data, int level, int len)
 
 
 static int
-gss_encode(void *app_data, void *from, int length, int level, void **to)
+gss_encode(void *app_data, const void *from, int length, int level, void **to)
 {
     OM_uint32 min_stat;
     gss_buffer_desc input, output;
@@ -144,7 +144,7 @@ gss_encode(void *app_data, void *from, int length, int level, void **to)
     struct gss_data *d = app_data;
 
     input.length = length;
-    input.value = from;
+    input.value = (void*) from;
     gss_wrap (&min_stat,
 			 d->context_hdl,
 			 level == prot_private,
@@ -182,7 +182,7 @@ sockaddr_to_gss_address (const struct sockaddr *sa,
     }
     default :
 	ftp_err("unknown address family %d", sa->sa_family);
-	
+
     }
 }
 
@@ -210,14 +210,14 @@ import_name(const char *kname, const char *host, gss_name_t *target_name)
 	OM_uint32 new_stat;
 	OM_uint32 msg_ctx = 0;
 	gss_buffer_desc status_string;
-	    
+
 	gss_display_status(&new_stat,
 			   min_stat,
 			   GSS_C_MECH_CODE,
 			   GSS_C_NO_OID,
 			   &msg_ctx,
 			   &status_string);
-	printf("Error importing name %s: %s\n", 
+	printf("Error importing name %s: %s\n",
 	       (char *)name.value,
 	       (char *)status_string.value);
 	gss_release_buffer(&new_stat, &status_string);
@@ -287,7 +287,7 @@ gss_auth(void *app_data, const char *host)
 		    return AUTH_ERROR;
 		continue;
 	    }
-	    
+
 	    gss_display_status(&new_stat,
 			       min_stat,
 			       GSS_C_MECH_CODE,
@@ -302,7 +302,7 @@ gss_auth(void *app_data, const char *host)
 
 	gss_release_buffer(&min_stat, &input);
 	if (output_token.length != 0) {
-	    base64_encode(output_token.value, output_token.length, &p);
+	    b64_encode(output_token.value, output_token.length, &p);
 	    gss_release_buffer(&min_stat, &output_token);
 	    ftp_cmd("ADAT %s", p);
 	    free(p);
@@ -323,7 +323,7 @@ gss_auth(void *app_data, const char *host)
 	    } else {
 		p+=5;
 		input.value = malloc(strlen(p));
-		input.length = base64_decode(p, input.value);
+		input.length = b64_decode(p, input.value);
 	    }
 	} else {
 	    if(ftp->fullcode != 235) {
