@@ -40,25 +40,24 @@ unsigned long int rdir_size(rdirectory *rdir)
 
 int rdir_parse(rdirectory *rdir, FILE *fp, const char *path, bool is_mlsd)
 {
-	char tmp[257];
-	rfile *f;
 	int r;
 	bool failed = false;
 
 	free(rdir->path);
-	rdir->path = 0;
+	rdir->path = NULL;
 	list_clear(rdir->files);
 	rdir->timestamp = time(0);
 
-	f = rfile_create();
+	rfile* f = rfile_create();
 
 	ftp_trace("*** start parsing directory listing of '%s' ***\n", path);
 
 	while(!feof(fp)) {
-		if(fgets(tmp, 256, fp) == 0)
+		char tmp[512];
+		if(fgets(tmp, sizeof(tmp), fp) == 0)
 			break;
 		strip_trailing_chars(tmp, "\r\n");
-		if(tmp[0] == 0)
+		if(!tmp[0])
 			break;
 		ftp_trace("%s\n", tmp);
 
@@ -69,9 +68,10 @@ int rdir_parse(rdirectory *rdir, FILE *fp, const char *path, bool is_mlsd)
 			list_clear(rdir->files);
 			failed = true;
 		} else if(r == 0)
-			list_additem(rdir->files, (void *)rfile_clone(f));
+			list_additem(rdir->files, rfile_clone(f));
 		/* else r == 1, ie a 'total ###' line, which isn't an error */
 	}
+  rfile_destroy(f);
 	ftp_trace("*** end parsing directory listing ***\n");
 	if(failed) {
 		if(list_numitem(rdir->files) == 0) {
