@@ -16,52 +16,48 @@
 
 rfile *rfile_create(void)
 {
-    rfile *f;
-
-    f = (rfile *)xmalloc(sizeof(rfile));
-
-    return f;
+  return xmalloc(sizeof(rfile));
 }
 
 rfile *rfile_clone(const rfile *f)
 {
-    rfile *nf = rfile_create();
-    nf->perm = xstrdup(f->perm);
-    nf->owner = xstrdup(f->owner);
-    nf->group = xstrdup(f->group);
-    nf->color = xstrdup(f->color);
-    nf->date = xstrdup(f->date);
-    nf->link = xstrdup(f->link);
-    nf->path = xstrdup(f->path);
-    nf->size = f->size;
-    nf->nhl = f->nhl;
-    nf->mtime = f->mtime;
+  rfile *nf = rfile_create();
+  nf->perm = xstrdup(f->perm);
+  nf->owner = xstrdup(f->owner);
+  nf->group = xstrdup(f->group);
+  nf->color = xstrdup(f->color);
+  nf->date = xstrdup(f->date);
+  nf->link = xstrdup(f->link);
+  nf->path = xstrdup(f->path);
+  nf->size = f->size;
+  nf->nhl = f->nhl;
+  nf->mtime = f->mtime;
 
-    return nf;
+  return nf;
 }
 
 void rfile_clear(rfile *f)
 {
-    free(f->perm);
-    free(f->owner);
-    free(f->group);
-    free(f->color);
-    free(f->date);
-    free(f->link);
-    free(f->path);
-    f->perm = f->owner = f->group = f->color = 0;
-    f->date = f->link = f->path = 0;
-    f->nhl = 0;
-    f->size = 0L;
-    f->mtime = (time_t)0;
+  free(f->perm);
+  free(f->owner);
+  free(f->group);
+  free(f->color);
+  free(f->date);
+  free(f->link);
+  free(f->path);
+  f->perm = f->owner = f->group = f->color = NULL;
+  f->date = f->link = f->path = NULL;
+  f->nhl = 0;
+  f->size = 0L;
+  f->mtime = (time_t)0;
 }
 
 void rfile_destroy(rfile *f)
 {
-    if(!f)
-        return;
-    rfile_clear(f);
-    free(f);
+  if (!f)
+    return;
+  rfile_clear(f);
+  free(f);
 }
 
 bool risdir(const rfile *f)
@@ -122,7 +118,7 @@ void rfile_fake(rfile *f, const char *path)
     free(f->group);
     f->group = xstrdup("group");
     free(f->link);
-    f->link = 0;
+    f->link = NULL;
     free(f->path);
     f->path = xstrdup(path);
     free(f->date);
@@ -307,15 +303,21 @@ static int rfile_parse_eplf(rfile *f, char *str, const char *dirpath)
 
     str++;
 
+    free(f->perm);
     f->perm = xstrdup("-rw-r--r--");
     f->size = 0L;
     f->mtime = 0;
-    f->link = 0;
+    free(f->link);
+    f->link = NULL;
     f->nhl = 0;
+    free(f->owner);
     f->owner = xstrdup("owner");
+    free(f->group);
     f->group = xstrdup("group");
+    free(f->date);
     f->date = xstrdup("Jan  0  1900");
-    f->path = 0;
+    free(f->path);
+    f->path = NULL;
 
     while((e = strqsep(&str, ',')) != 0) {
         switch(*e) {
@@ -348,10 +350,10 @@ static int rfile_parse_eplf(rfile *f, char *str, const char *dirpath)
  */
 static int rfile_parse_unix(rfile *f, char *str, const char *dirpath)
 {
-    char *cf;
-    char *e;
-    char *m=0, *d=0, *y=0;
-    char *saved_field[5];
+    char *cf = NULL;
+    char *e = NULL;
+    char *m = NULL, *d = NULL, *y = NULL;
+    char *saved_field[5] = { NULL };
     bool time_parsed = false;
 
     /* real unix ls listing:
@@ -406,6 +408,7 @@ static int rfile_parse_unix(rfile *f, char *str, const char *dirpath)
      * ----------^
      * so we assume the permission string is exactly 10 characters
      */
+    free(f->perm);
     f->perm = xstrndup(cf, 10);
     cf += 10;
 
@@ -442,7 +445,9 @@ static int rfile_parse_unix(rfile *f, char *str, const char *dirpath)
         /* ls -l */
         f->nhl = atoi(saved_field[0]);
         free(saved_field[0]);
+        free(f->owner);
         f->owner = saved_field[1];
+        free(f->group);
         f->group = saved_field[2];
         f->size = strtoull(saved_field[3],NULL,10);
         free(saved_field[3]);
@@ -456,7 +461,9 @@ static int rfile_parse_unix(rfile *f, char *str, const char *dirpath)
         /* ls -lG */
         f->nhl = atoi(saved_field[0]);
         free(saved_field[0]);
+        free(f->owner);
         f->owner = saved_field[1];
+        free(f->group);
         f->group = xstrdup("group");
         f->size = strtoull(saved_field[2],NULL,10);
         free(saved_field[2]);
@@ -468,7 +475,9 @@ static int rfile_parse_unix(rfile *f, char *str, const char *dirpath)
     {
         free(saved_field[0]);
         f->nhl = 0;
-        f->owner = xstrdup("owner");;
+        free(f->owner);
+        f->owner = xstrdup("owner");
+        free(f->group);
         f->group = xstrdup("group");
         f->size = strtoull(saved_field[1],NULL,10);
         free(saved_field[1]);
@@ -483,7 +492,9 @@ static int rfile_parse_unix(rfile *f, char *str, const char *dirpath)
 
             f->nhl = atoi(saved_field[0]);
             free(saved_field[0]);
+            free(f->owner);
             f->owner = saved_field[1];
+            free(f->group);
             f->group = saved_field[2];
             f->size = strtoull(saved_field[3],NULL,10);
             free(saved_field[3]);
@@ -510,6 +521,7 @@ static int rfile_parse_unix(rfile *f, char *str, const char *dirpath)
 
                 time(&now);
 
+                free(f->date);
                 bool success = true;
                 if(f->mtime != (time_t)-1 &&
                    (now > f->mtime + 6L * 30L * 24L * 60L * 60L  /* Old. */
@@ -538,6 +550,7 @@ static int rfile_parse_unix(rfile *f, char *str, const char *dirpath)
     }
 
     if(!time_parsed) {
+        free(f->date);
         if (asprintf(&f->date, "%s %2s %5s", m, d, y) == -1)
         {
           free(m);
@@ -560,10 +573,11 @@ static int rfile_parse_unix(rfile *f, char *str, const char *dirpath)
     e = strstr(cf, " -> ");
     if(e) {
         *e = 0;
+        free(f->link);
         f->link = xstrdup(e+4);
     }
 
-
+    free(f->path);
     if (asprintf(&f->path, "%s/%s", strcmp(dirpath, "/") ? dirpath : "", cf) == -1)
     {
       f->path = NULL;
@@ -616,6 +630,7 @@ static int rfile_parse_dos(rfile *f, char *str, const char *dirpath)
         time_t now;
         time(&now);
 
+        free(f->date);
         bool success = true;
         if(f->mtime != (time_t)-1 && (now > f->mtime + 6L * 30L * 24L * 60L * 60L  /* Old. */
                                       || now < f->mtime - 60L * 60L))   /* In the future. */
@@ -632,6 +647,7 @@ static int rfile_parse_dos(rfile *f, char *str, const char *dirpath)
         }
     }
 
+    free(f->perm);
     f->perm = xstrdup("-rw-r--r--");
 
     NEXT_FIELD;
@@ -643,13 +659,17 @@ static int rfile_parse_dos(rfile *f, char *str, const char *dirpath)
     }
 
     f->nhl = 1;
+    free(f->owner);
     f->owner = xstrdup("owner");
+    free(f->group);
     f->group = xstrdup("group");
-    f->link = 0;
+    free(f->link);
+    f->link = NULL;
 
     while(cf && *cf == ' ')
         ++cf;
 
+    free(f->path);
     if (asprintf(&f->path, "%s/%s", strcmp(dirpath, "/") ? dirpath : "", cf) == -1)
     {
       f->path = NULL;
@@ -674,6 +694,7 @@ static int rfile_parse_mlsd(rfile *f, char *str, const char *dirpath)
 
     e = strchr(str, ' ');
     if(e) {
+      free(f->path);
       if (asprintf(&f->path, "%s/%s",
                  strcmp(dirpath, "/") ? dirpath : "", base_name_ptr(e+1)) == -1)
       {
@@ -684,13 +705,18 @@ static int rfile_parse_mlsd(rfile *f, char *str, const char *dirpath)
     } else
         return -1;
 
-    f->perm = 0;
+    free(f->perm);
+    f->perm = NULL;
     f->size = 0L;
     f->mtime = 0;
-    f->link = 0;
+    free(f->link);
+    f->link = NULL;
     f->nhl = 0;
+    free(f->owner);
     f->owner = xstrdup("owner");
+    free(f->group);
     f->group = xstrdup("group");
+    free(f->date);
     f->date = xstrdup("Jan  0  1900");
 
     while((e = strqsep(&str, ';')) != 0) {
@@ -775,8 +801,6 @@ int rfile_parse(rfile *f, char *str, const char *dirpath, bool is_mlsd)
             r = rfile_parse_dos(f, tmp, dirpath);
         else if(ftp->LIST_type == ltEplf)
             r = rfile_parse_eplf(f, tmp, dirpath);
-/*      else if(ftp->LIST_type == ltMlsd)
-        r = rfile_parse_mlsd(f, tmp, dirpath);*/
 
         free(tmp);
 
@@ -792,9 +816,6 @@ int rfile_parse(rfile *f, char *str, const char *dirpath, bool is_mlsd)
             } else if(ftp->LIST_type == ltEplf) {
                 ftp->LIST_type = ltUnix;
                 ftp_trace("EPLF output parsing failed, trying UNIX\n");
-/*          } else if(ftp->LIST_type == ltMlsd) {
-                ftp->LIST_type = ltUnix;
-                ftp_trace("MLSD output parsing failed, trying UNIX\n");*/
             }
         } else
             return r;
