@@ -11,7 +11,6 @@
  */
 
 #include "syshdr.h"
-#include "get.h"
 #include "ftp.h"
 #include "gvars.h"
 #include "strq.h"
@@ -26,6 +25,30 @@
 # include <regex.h>
 #endif
 
+#define GET_INTERACTIVE 1
+#define GET_APPEND (1 << 1)
+#define GET_PRESERVE (1 << 2)
+#define GET_PARENTS (1 << 3)
+#define GET_RECURSIVE (1 << 4)
+#define GET_VERBOSE (1 << 5)
+#define GET_FORCE (1 << 6)
+#define GET_FORCE_NEWER (1 << 22)
+#define GET_NO_DEREFERENCE (1 << 7)
+#define GET_NEWER (1 << 8)
+#define GET_DELETE_AFTER (1 << 9)
+#define GET_UNIQUE (1 << 10)
+#define GET_RESUME (1 << 11)
+#define GET_TAGGED (1 << 12)
+#define GET_NOHUP (1 << 13)
+#define GET_SKIP_EXISTING (1 << 14)
+#define GET_BACKGROUND (1 << 15)
+#define GET_ASCII (1 << 16)
+#define GET_BINARY (1 << 17)
+#define GET_CHMOD (1 << 18)
+#define GET_CHGRP (1 << 19)
+#define GET_OUTPUT_FILE (1 << 20)  /* --output=FILE (else --output=DIR) */
+#define GET_SKIP_EMPTY (1 << 21)
+
 static bool get_quit = false;
 static bool get_owbatch = false;
 static bool get_delbatch = false;
@@ -56,6 +79,7 @@ static void print_get_syntax(void)
       "      --dir-rx-mask=REGEXP\n"
       "                       enter only directories matching REGEXP pattern\n"
       "  -f, --force          overwrite existing destinations, never prompt\n"
+      "  -F, --force-newer    do not use cached information with --newer\n"
       "  -e, --skip-empty     skip empty files\n"
       "  -H, --nohup          transfer files in background (nohup mode), quits yafc\n"
       "  -i, --interactive    prompt before each transfer\n"
@@ -151,7 +175,7 @@ static void get_preserve_attribs(const rfile *fi, char *dest)
             perror(dest);
     }
     if(!risdir(fi)) {
-        t = ftp_filetime(fi->path);
+        t = ftp_filetime(fi->path, true);
         if(t != (time_t)-1) {
             struct utimbuf u;
             u.actime = t;
@@ -271,7 +295,7 @@ static int getfile(const rfile *fi, unsigned int opt,
             how = getAppend;
         else if(test(opt, GET_NEWER)) {
             struct tm *fan = gmtime(&sb.st_mtime);
-            time_t ft = ftp_filetime(fi->path);
+            time_t ft = ftp_filetime(fi->path, test(opt, GET_FORCE_NEWER));
             sb.st_mtime = gmt_mktime(fan);
 
             ftp_trace("get -n: remote file: %s", ctime(&ft));
@@ -291,7 +315,7 @@ static int getfile(const rfile *fi, unsigned int opt,
         } else if(!test(opt, GET_RESUME)) {
             if(!get_owbatch && !gvSighupReceived) {
                 struct tm *fan = gmtime(&sb.st_mtime);
-                time_t ft = ftp_filetime(fi->path);
+                time_t ft = ftp_filetime(fi->path, test(opt, GET_FORCE_NEWER));
                 int a;
                 char *e;
 
@@ -622,6 +646,7 @@ void cmd_get(int argc, char **argv)
         {"interactive", no_argument, 0, 'i'},
         {"skip-empty", no_argument, 0, 'e'},
         {"force", no_argument, 0, 'f'},
+        {"force-newer", no_argument, 0, 'F'},
         {"logfile", required_argument, 0, 'L'},
         {"mask", required_argument, 0, 'm'},
 #ifdef HAVE_REGEX
@@ -672,7 +697,7 @@ void cmd_get(int argc, char **argv)
     get_skip_empty = false;
 
     optind = 0; /* force getopt() to re-initialize */
-    while((c=getopt_long(argc, argv, "abHc:dDeio:fL:tnpPvqrRsuT:m:M:",
+    while((c=getopt_long(argc, argv, "abHc:dDeio:fFL:tnpPvqrRsuT:m:M:",
                          longopts, 0)) != EOF)
     {
         switch(c) {
@@ -732,7 +757,7 @@ void cmd_get(int argc, char **argv)
             unquote(optarg);
             ret = regcomp(&get_dir_rx_mask, optarg, REG_EXTENDED);
             if(ret != 0) {
-                regerror(ret, &get_dir_rx_mask, get_rx_errbuf, 128);
+                regerror(ret, &get_dir_rx_mask, get_rx_errbuf, sizeof(get_rx_errbuf) - 1);
                 ftp_err(_("Regexp '%s' failed: %s\n"), optarg, get_rx_errbuf);
                 return;
             } else
@@ -745,6 +770,9 @@ void cmd_get(int argc, char **argv)
           case 'f':
             opt |= GET_FORCE;
             break;
+          case 'F':
+            opt |= GET_FORCE_NEWER;
+            break;
         case 'm': /* --mask */
             free(get_glob_mask);
             get_glob_mask = xstrdup(optarg);
@@ -759,7 +787,7 @@ void cmd_get(int argc, char **argv)
             unquote(optarg);
             ret = regcomp(&get_rx_mask, optarg, REG_EXTENDED);
             if(ret != 0) {
-                regerror(ret, &get_rx_mask, get_rx_errbuf, 128);
+                regerror(ret, &get_rx_mask, get_rx_errbuf, sizeof(get_rx_errbuf) - 1);
                 ftp_err(_("Regexp '%s' failed: %s\n"), optarg, get_rx_errbuf);
                 return;
             } else
