@@ -11,8 +11,8 @@
  */
 
 #include "syshdr.h"
-#include "ftp.h"
-#include "linklist.h"
+#include "ftp/ftp.h"
+#include "libmhe/linklist.h"
 #include "stats.h"
 
 /* time (in seconds) before a cached directory times out, 0 == never */
@@ -175,60 +175,78 @@ bool gvJmpBufSet = false;
 
 void gvars_destroy(void)
 {
-	free(gvEditor);
+  free(gvEditor);
   gvEditor = NULL;
-	free(gvAnonPasswd);
+  free(gvAnonPasswd);
   gvAnonPasswd = NULL;
-	free(gvPrompt1);
+  free(gvPrompt1);
   gvPrompt1 = NULL;
-	free(gvPrompt2);
+  free(gvPrompt2);
   gvPrompt2 = NULL;
-	free(gvPrompt3);
+  free(gvPrompt3);
   gvPrompt3 = NULL;
-	free(gvLocalHomeDir);
+  free(gvLocalHomeDir);
   gvLocalHomeDir = NULL;
-	free(gvLocalPrevDir);
+  free(gvLocalPrevDir);
   gvLocalPrevDir = NULL;
-	free(gvUsername);
+  free(gvUsername);
   gvUsername = NULL;
-	free(gvHistoryFile);
+  free(gvHistoryFile);
   gvHistoryFile = NULL;
-	free(gvNohupMailAddress);
+  free(gvNohupMailAddress);
   gvNohupMailAddress = NULL;
-	free(gvSendmailPath);
+  free(gvSendmailPath);
   gvSendmailPath = NULL;
-	free(gvLocalHost);
+  free(gvLocalHost);
   gvLocalHost = NULL;
-	free(gvTransferBeginString);
+  free(gvTransferBeginString);
   gvTransferBeginString = NULL;
-	free(gvTransferString);
+  free(gvTransferString);
   gvTransferString = NULL;
-	free(gvTransferEndString);
+  free(gvTransferEndString);
   gvTransferEndString = NULL;
-	free(gvSSHOptions);
+  free(gvSSHOptions);
   gvSSHOptions = NULL;
-	free(gvWorkingDirectory);
+  free(gvWorkingDirectory);
   gvWorkingDirectory = NULL;
-	list_free(gvAsciiMasks);
+  list_free(gvAsciiMasks);
   gvAsciiMasks = NULL;
-	list_free(gvIgnoreMasks);
+  list_free(gvIgnoreMasks);
   gvIgnoreMasks = NULL;
-	list_free(gvAliases);
+  list_free(gvAliases);
   gvAliases = NULL;
-	list_free(gvLocalTagList);
+  list_free(gvLocalTagList);
   gvLocalTagList = NULL;
-	list_free(gvBookmarks);
+  list_free(gvBookmarks);
   gvBookmarks = NULL;
   list_free(gvFtpList);
   gvFtpList = NULL;
-	url_destroy(gvDefaultUrl);
+  url_destroy(gvDefaultUrl);
   gvDefaultUrl = NULL;
-	url_destroy(gvLocalUrl);
+  url_destroy(gvLocalUrl);
   gvLocalUrl = NULL;
-	stats_destroy(gvStatsTransfer);
+  stats_destroy(gvStatsTransfer);
   gvStatsTransfer = NULL;
+  free(gvTerm);
+  gvTerm = NULL;
+  free(gvXtermTitle1);
+  gvXtermTitle1 = NULL;
+  free(gvXtermTitle2);
+  gvXtermTitle2 = NULL;
+  free(gvXtermTitle3);
+  gvXtermTitle3 = NULL;
+  free(gvXtermTitleTerms);
+  gvXtermTitleTerms = NULL;
+  list_free(gvDefaultMechanism);
+  gvDefaultMechanism = NULL;
+  free(gvTransferXtermString);
+  gvTransferXtermString = NULL;
+  list_free(gvTransferFirstMasks);
+  gvTransferFirstMasks = NULL;
+  list_free(gvProxyExclude);
+  gvProxyExclude = NULL;
 
-	if(gvLogfp)
-		fclose(gvLogfp);
-	gvLogfp = 0;
+  if(gvLogfp)
+    fclose(gvLogfp);
+  gvLogfp = NULL;
 }
