@@ -24,8 +24,6 @@
 #elif defined(HAVE_OPENSSL_UI_COMPAT_H)
 #include <openssl/ui_compat.h>
 #else /* des_read_pw_string and UI_UTIL_read_pw_string are not available */
-#include <fcntl.h>
-#include <sys/ioctl.h>
 #include <termios.h>
 #if !defined(HAVE_DECL_IUCLC) || !HAVE_DECL_IUCLC
 #define IUCLC 0
@@ -62,13 +60,12 @@ static char* vinput_read_string(const char* fmt, va_list ap)
 	char tmp[257];
 
 	vfprintf(stderr, fmt, ap);
-	if(fgets(tmp, 256, stdin) == 0)
+	if(fgets(tmp, sizeof(tmp), stdin) == 0)
 		return 0;
 	if(tmp[0] == '\n')
 		/* return an empty string, "" */
 		return xstrdup("");
-	tmp[256] = 0;
-	size_t l = strlen(tmp);
+	const size_t l = strlen(tmp);
 	/* strip carriage return */
 	if(tmp[l-1] == '\n')
 		tmp[l-1] = 0;
@@ -80,7 +77,7 @@ char* input_read_string(const char* fmt, ...)
 {
   va_list ap;
   va_start(ap, fmt);
-	char* ret = vinput_read_string(fmt, ap);
+  char* ret = vinput_read_string(fmt, ap);
   va_end(ap);
   return ret;
 }
@@ -339,6 +336,7 @@ int ask(int opt, int def, const char *prompt, ...)
 	va_start(ap, prompt);
 	if (vasprintf(&e, prompt, ap) == -1)
   {
+    va_end(ap);
     fprintf(stderr, _("Failed to allocate memory.\n"));
     return -1;
   }
