@@ -126,10 +126,12 @@ void init_yafc(void)
 	if(!gvLocalHomeDir)
 		gvLocalHomeDir = xstrdup(getenv("HOME"));
 
+  char* curdir = getcwd(NULL, 0);
 	gvWorkingDirectory = path_absolute(
 		gvWorkingDirectory ? gvWorkingDirectory : "~/.yafc",
-		get_local_curdir(),
+    curdir,
 		gvLocalHomeDir);
+  free(curdir);
 
 	gvAnonPasswd = xstrdup("anonymous@");
 
@@ -336,7 +338,7 @@ int main(int argc, char **argv, char **envp)
 			override_verbose = true;
 			break;
 		case 'V':
-			printf(PACKAGE " " VERSION " (" HOSTTYPE ")\n");
+			printf(PACKAGE " " VERSION "\n");
 			return 0;
 		case 'w':
 			wait_time = atoi(optarg);
@@ -379,6 +381,8 @@ int main(int argc, char **argv, char **envp)
 		parse_rc(tmp, false);
 		free(tmp);
 	}
+  free(configfile);
+  configfile = NULL;
 
 	if(gvReadNetrc)
 		parse_rc("~/.netrc", false);
