@@ -32,7 +32,7 @@
 #endif
 
 #ifdef HAVE_CONFIG_H
-# include "config.h"
+# include "../config.h"
 #endif
 
 #ifdef HAVE_SYS_TYPES_H
@@ -47,24 +47,19 @@
 #include <string.h>
 #include <stdlib.h>
 
-
 #include <ctype.h>
 #include <signal.h>
 #include <stdarg.h>
 #include <setjmp.h>
 
 #include <errno.h>
-#include <grp.h>
 
-#include "xmalloc.h"
+#include "libmhe/xmalloc.h"
 
 #include <sys/ioctl.h>
 
-#if defined HAVE_DECL_ASPRINTF && !HAVE_DECL_ASPRINTF
-int asprintf(char **strp, const char *format, ...) YAFC_PRINTF(2, 3);
-#endif
-#if defined HAVE_DECL_VASPRINTF && !HAVE_DECL_VASPRINTF
-int vasprintf(char **strp, const char *format, va_list ap);
+#ifdef HAVE_GRP_H
+# include <grp.h>
 #endif
 
 #ifdef HAVE_UNISTD_H
@@ -76,7 +71,7 @@ int vasprintf(char **strp, const char *format, va_list ap);
 #endif
 
 #ifdef HAVE_BSD_STRING_H
-#include <bsd/string.h>
+# include <bsd/string.h>
 #endif
 
 #ifdef HAVE_UNAME
@@ -111,6 +106,9 @@ int vasprintf(char **strp, const char *format, va_list ap);
 #ifdef HAVE_SYS_STAT_H
 # include <sys/stat.h>
 #endif
+#ifdef HAVE_FCNTL_H
+# include <fcntl.h>
+#endif
 
 /* networking headers */
 #ifdef HAVE_SYS_SOCKET_H
@@ -158,8 +156,8 @@ extern int read_history ();
 #endif /* HAVE_READLINE_HISTORY */
 
 #ifdef HAVE_LIBEDIT
-#include <editline/readline.h>
-#define HAVE_LIBREADLINE
+# include <editline/readline.h>
+# define HAVE_LIBREADLINE
 #endif
 
 #if defined(HAVE_LIBEDIT) || (defined(HAVE_LIBREADLINE) && RL_READLINE_VERSION < 0x0602)
@@ -167,25 +165,27 @@ typedef CPPFunction rl_completion_func_t;
 #endif
 
 #ifdef HAVE_FNMATCH_GNU
-#include <fnmatch.h>
+# include <fnmatch.h>
 #else
-#include "fnmatch.h"  /* our own, in lib/ */
+# include "../lib/fnmatch.h"  /* our own, in lib/ */
 #endif
 
 #if defined(HAVE_GETOPT_LONG) && defined(HAVE_GETOPT_H)
 # include <getopt.h>
 #else
-# include "getopt.h"  /* our own, in lib/ */
+# include "../lib/getopt.h"  /* our own, in lib/ */
 #endif
 
-#define min(a, b) ((a) < (b) ? (a) : (b))
+#if defined HAVE_DECL_ASPRINTF && !HAVE_DECL_ASPRINTF
+int asprintf(char **strp, const char *format, ...) YAFC_PRINTF(2, 3);
+#endif
+#if defined HAVE_DECL_VASPRINTF && !HAVE_DECL_VASPRINTF
+int vasprintf(char **strp, const char *format, va_list ap);
+#endif
 
 #ifdef HAVE_KERBEROS
 # define SECFTP
-# include "security.h"  /* our own, in lib/ */
-# ifndef HAVE_DECL_STRLCPY
-size_t strlcpy (char *dst, const char *src, size_t dst_sz);
-# endif
+# include "../lib/security.h"  /* our own, in lib/ */
 #endif
 
 /* NLS stuff (Native Language Support) */
@@ -218,11 +218,11 @@ typedef void (*sighandler_t)(int);
 #define STD_SHELL "/bin/sh"
 
 #ifndef MIN
-#define MIN(a, b) (a) < (b) ? (a) : (b)
+# define MIN(a, b) (a) < (b) ? (a) : (b)
 #endif
 
 #ifndef MAX
-#define MAX(a, b) (a) < (b) ? (b) : (a)
+# define MAX(a, b) (a) < (b) ? (b) : (a)
 #endif
 
 #endif
